@@ -53,6 +53,7 @@ extern int allhostsknown(struct channel *);
 extern int burstjoins(struct channel *);
 extern int isq(char *);
 extern int isservice(char *);
+extern int istrusted(char *);
 extern int isme(char *);
 extern int isop(struct channel *, char *);
 extern int isvalidlogon(struct channel *, char *);
@@ -161,9 +162,9 @@ extern void linenoise(void);
 extern void checkstoned(void);
 extern void setuserhost(char *, char *);
 extern void sethostquerystatus(char *, int);
-extern void banuser(struct channel *, char *);
-extern void unbanuser(struct channel *, char *);
-extern void kickuser(struct channel *, char *, char *);
+extern void banuser(struct channel *, time_t, char *);
+extern void unbanuser(struct channel *, time_t, char *);
+extern void kickuser(struct channel *, time_t, char *, char *);
 extern void sendreply(char *, int, int, int, char *);
 extern void sendchannelnotice(struct channel *, int, char *);
 extern void addcommand(struct channel *, char *, int, char *, char *, char *);
