@@ -34,8 +34,73 @@ int serverconnection(void);
 int registerconnection(void);
 int handleserverdata(void);
 int processtimeds(void);
+void establishconnection(void);
 void reconnect(void);
 
+void establishconnection()
+{
+#ifdef DEBUG
+        oer_debug(OER_DEBUG_FLOOD, "establishconnection()\n");
+#endif
+        /* loop until a fatal error */
+        while(!mystate->bailout) {
+                mystate->now = time(NULL);
+                switch(serverconnection()) {
+                case OER_SERVERCONNECTION_ERR_SOCKET:
+#ifdef DEBUG
+                        oer_debug(OER_DEBUG_FATAL, "establishconnection->socket() failed, exiting.\n");
+#endif
+                        mystate->bailout = 1;
+                        return;
+		case OER_SERVERCONNECTION_ERR_GETHOSTNAME:
+#ifdef DEBUG
+                        oer_debug(OER_DEBUG_FATAL, "establishconnection->gethostname() failed, exiting.\n");
+#endif
+                        mystate->bailout = 1;
+                        return;
+                case OER_SERVERCONNECTION_ERR_GETHOSTBYNAME_RETRY:
+#ifdef DEBUG
+                        oer_debug(OER_DEBUG_ERROR, "establishconnection->gethostbyname() temporary error, retrying.\n");
+#endif
+                        sleep(OER_WAIT_BETWEEN_CONNECTION_ATTEMPTS);
+                        break;
+		case OER_SERVERCONNECTION_ERR_GETSERVER_RETRY:
+#ifdef DEBUG
+                        oer_debug(OER_DEBUG_ERROR, "establishconnection->getserver() temporary error, retrying.\n");
+#endif
+                        sleep(OER_WAIT_BETWEEN_CONNECTION_ATTEMPTS);
+                        break;
+                case OER_SERVERCONNECTION_ERR_GETHOSTBYNAME:
+#ifdef DEBUG
+                        oer_debug(OER_DEBUG_FATAL, "establishconnection->gethostbyname() fatal error, exiting.\n");
+#endif
+                        mystate->bailout = 1;
+                        return;
+		case OER_SERVERCONNECTION_ERR_BIND:
+#ifdef DEBUG
+                        oer_debug(OER_DEBUG_FATAL, "establishconnection->bind() fatal error, exiting.\n");
+#endif
+                        mystate->bailout = 1;
+                        return;
+                case OER_SERVERCONNECTION_ERR_CONNECT_RETRY:
+#ifdef DEBUG
+                        oer_debug(OER_DEBUG_ERROR, "establishconnection->connect() temporary error, retrying.\n");
+#endif
+                        sleep(OER_WAIT_BETWEEN_CONNECTION_ATTEMPTS);
+                        break;
+                case OER_SERVERCONNECTION_ERR_CONNECT:
+#ifdef DEBUG
+                        oer_debug(OER_DEBUG_FATAL, "establishconnection->connect() fatal error, exiting.\n");
+#endif
+                        mystate->bailout = 1;
+                        return;
+                case OER_SERVERCONNECTION_ALREADY_CONNECTED:
+                case OER_SERVERCONNECTION_EVERYTHING_OK:
+                        return;
+                }
+        }
+}
+
 void reconnect()
 {
 	char stringbuffer[WRITE_BUFFER_LENGTH + 1];
@@ -70,6 +135,10 @@ void reconnect()
 		oer_debug(OER_DEBUG_INFO, "reconnect->sleeping 30 seconds to avoid throttling\n");
 #endif
 		sleep(OER_RECONNECT_DELAY);
+                establishconnection();
+                if(mystate->bailout) {
+                        exit(EXIT_FAILURE);
+                }
 		mystate->reconnect = OER_RECONNECT_NONE;
 		break;
 	case OER_RECONNECT_STONED:
@@ -85,6 +154,10 @@ void reconnect()
 		oer_debug(OER_DEBUG_INFO, "reconnect->sleeping 30 seconds to avoid throttling\n");
 #endif
 		sleep(OER_RECONNECT_DELAY);
+		establishconnection();
+                if(mystate->bailout) {
+                        exit(EXIT_FAILURE);
+                }
 		mystate->reconnect = OER_RECONNECT_NONE;
 		break;
 	case OER_RECONNECT_ERROR:
@@ -109,6 +182,10 @@ void reconnect()
 		oer_debug(OER_DEBUG_INFO, "reconnect->sleeping 30 seconds to avoid throttling\n");
 #endif
 		sleep(OER_RECONNECT_DELAY);
+                establishconnection();
+                if(mystate->bailout) {
+                        exit(EXIT_FAILURE);
+                }
 		mystate->reconnect = OER_RECONNECT_NONE;
 		break;
 	}
