@@ -27,8 +27,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 extern int serverconnection(void);
 extern int registerconnection(void);
 extern int handleserverdata(void);
-extern int processmmodes(void);
 extern int processtimeds(void);
+extern void establishconnection(void);
 extern void reconnect(void);
 
 
