@@ -58,7 +58,7 @@ void parseirc(char *serveroutput)
 	char nick[NICKLEN + 1];
 	char nick2[NICKLEN + 1];
 	char temp_nick[STRINGLEN + 1];
-	char target[NICKLEN + 1];
+	char target[STRINGLEN + 1];
 	char m;
         char *restptr;
         char *ptr;
@@ -666,7 +666,7 @@ void parseirc(char *serveroutput)
 			return;
 		}
 		restpos = 0;
-		if((restpos = parse(restptr, restpos, " ", target, NICKLEN, 0)) < 0) {
+		if((restpos = parse(restptr, restpos, " ", target, STRINGLEN, 0)) < 0) {
 			return;
 		}
 		if(isme(target)) {
@@ -744,7 +744,7 @@ void parseirc(char *serveroutput)
 		bans = 0;
 		deops = 0;
 		while(1) {
-			nrestpos = parse(restptr, restpos, " ", target, NICKLEN, 0);
+			nrestpos = parse(restptr, restpos, " ", target, STRINGLEN, 0);
 			if(nrestpos == restpos || nrestpos < 0) {
 				break;
 			}
@@ -1098,14 +1098,12 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 		if(haschanflags(this, "U") && !isatleastop(this, nick, userhost)) {
                         return;
                 }
-		if(!isatleastopnow(this, nick, userhost)) {
+		if(!isatleastopnow(this, nick, userhost) || !strlen(restptr) || !this->i_am_op) {
 			return;
 		}
-		if(!strlen(restptr)) {
-			return;
-		}
-		if(this->i_am_op) {
-			setnewtopic(this, nick, restptr);
+		if(!setnewtopic(this, nick, restptr)) {
+			snprintf(outstring, WRITE_BUFFER_LENGTH, "setnewtopic() failed");
+			sendreply((tochan) ? channel : nick, tochan, 0, 0, outstring);
 		}
 		return;
 	case OER_WHICHCOMMAND_TOPIC_ADD:
@@ -1122,14 +1120,12 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 		if(haschanflags(this, "U") && !isatleastop(this, nick, userhost)) {
                         return;
                 }
-		if(!isatleastopnow(this, nick, userhost)) {
+		if(!isatleastopnow(this, nick, userhost) || !strlen(restptr) || !this->i_am_op) {
 			return;
 		}
-		if(!strlen(restptr)) {
-			return;
-		}
-		if(this->i_am_op) {
-			addnewtopic(this, nick, restptr);
+		if(!addnewtopic(this, nick, restptr)) {
+			snprintf(outstring, WRITE_BUFFER_LENGTH, "addnewtopic() failed");
+			sendreply((tochan) ? channel : nick, tochan, 0, 0, outstring);
 		}
 		return;
 	case OER_WHICHCOMMAND_TOPIC_DEL:
@@ -1146,18 +1142,16 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 		if(haschanflags(this, "U") && !isatleastop(this, nick, userhost)) {
                         return;
                 }
-                if(!isatleastopnow(this, nick, userhost)) {
+                if(!isatleastopnow(this, nick, userhost) || !strlen(restptr) || !this->i_am_op) {
                         return;
                 }
-		if(!strlen(restptr)) {
+		if(!deltopic(this, atoi(restptr), topic)) {
+			snprintf(outstring, WRITE_BUFFER_LENGTH, "deltopic() failed");
+			sendreply((tochan) ? channel : nick, tochan, 0, 0, outstring);
 			return;
 		}
-		if(this->i_am_op) {
-			if(deltopic(this, atoi(restptr), topic)) {
-				snprintf(outstring, WRITE_BUFFER_LENGTH, "deleted Topic #%d: %s", atoi(restptr), topic);
-				sendreply((tochan) ? channel : nick, tochan, 0, 0, outstring);
-			}
-		}
+		snprintf(outstring, WRITE_BUFFER_LENGTH, "deleted Topic #%d: %s", atoi(restptr), topic);
+		sendreply((tochan) ? channel : nick, tochan, 0, 0, outstring);
 		return;
 	case OER_WHICHCOMMAND_TOPIC_EDIT:
 #ifdef DEBUG
@@ -1180,11 +1174,12 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 		if((ppos = parse(restptr, ppos, " ", p1, STRINGLEN, 0)) < 0) {
 			return;
 		}
-		if(!strlen(p1) || !strlen(restptr + ppos)) {
+		if(!strlen(p1) || !strlen(restptr + ppos) || !this->i_am_op) {
 			return;
 		}
-		if(this->i_am_op) {
-			edittopic(this, nick, restptr + ppos, atoi(p1));
+		if(!edittopic(this, nick, restptr + ppos, atoi(p1))) {
+			snprintf(outstring, WRITE_BUFFER_LENGTH, "edittopic() failed");
+			sendreply((tochan) ? channel : nick, tochan, 0, 0, outstring);
 		}
 		return;
 	case OER_WHICHCOMMAND_TOPIC_INS:
@@ -1208,11 +1203,12 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 		if((ppos = parse(restptr, ppos, " ", p1, STRINGLEN, 0)) < 0) {
 			return;
 		}
-		if(!strlen(p1) || !strlen(restptr + ppos)) {
+		if(!strlen(p1) || !strlen(restptr + ppos) || !this->i_am_op) {
 			return;
 		}
-		if(this->i_am_op) {
-			insertnewtopic(this, nick, restptr + ppos, atoi(p1));
+		if(!insertnewtopic(this, nick, restptr + ppos, atoi(p1))) {
+			snprintf(outstring, WRITE_BUFFER_LENGTH, "insertnewtopic() failed");
+			sendreply((tochan) ? channel : nick, tochan, 0, 0, outstring);
 		}
 		return;
 	case OER_WHICHCOMMAND_TOPIC_LIST:
@@ -1271,12 +1267,10 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 		if(haschanflags(this, "U") && !isatleastop(this, nick, userhost)) {
                         return;
                 }
-                if(!isatleastopnow(this, nick, userhost)) {
+                if(!isatleastopnow(this, nick, userhost) || !this->i_am_op) {
                         return;
                 }
-		if(this->i_am_op) {
-			this->topic_change = 1;
-		}
+		this->topic_change = 1;
 		return;
 	case OER_WHICHCOMMAND_TOPIC_SWAP:
 #ifdef DEBUG
@@ -1302,11 +1296,12 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 		if((ppos = parse(restptr, ppos, " ", p2, STRINGLEN, 0)) < 0) {
 			return;
 		}
-		if(!strlen(p1) || !strlen(p2)) {
+		if(!strlen(p1) || !strlen(p2) || !this->i_am_op) {
 			return;
 		}
-		if(this->i_am_op) {
-			swaptopic(this, atoi(p1), atoi(p2));
+		if(!swaptopic(this, atoi(p1), atoi(p2))) {
+			snprintf(outstring, WRITE_BUFFER_LENGTH, "swaptopic() failed");
+			sendreply((tochan) ? channel : nick, tochan, 0, 0, outstring);
 		}
 		return;
 	case OER_WHICHCOMMAND_LOCK:
@@ -1371,8 +1366,8 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 			return;
 		}
 		snprintf(outstring, WRITE_BUFFER_LENGTH, "random ban kick by %s\n", nick);
-		banuser(this, u->nick);
-		kickuser(this, u->nick, outstring);
+		banuser(this, mystate->now - 1, u->nick);
+		kickuser(this, mystate->now, u->nick, outstring);
                 return;
 	case OER_WHICHCOMMAND_RANDOM_KICK:
 #ifdef DEBUG
@@ -1394,7 +1389,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 			return;
 		}
 		snprintf(outstring, WRITE_BUFFER_LENGTH, "random kick by %s\n", nick);
-		kickuser(this, u->nick, outstring);
+		kickuser(this, mystate->now, u->nick, outstring);
 		return;
 	case OER_WHICHCOMMAND_SYNC:
 #ifdef DEBUG
@@ -1481,9 +1476,13 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
                 }
 		if(!strlen(restptr)) {
 			/* the messager wants to be opped */
-			if(!isopnow(this, nick) && (haschanflags(this, "u") && isallowedop(this, nick))) {
-				mmode_new(this, mystate->now, "+o", nick);
+			if(isopnow(this, nick)) {
+				return;
 			}
+			if(haschanflags(this, "u") && !isallowedop(this, nick)) {
+				return;
+			}
+			mmode_new(this, mystate->now, "+o", nick);
 			return;
 		}
 		/* op all given nicks */
@@ -1494,9 +1493,13 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 				break;
 			}
 			ppos = nppos;
-			if(!isopnow(this, p1) && (haschanflags(this, "u") && isallowedop(this, p1))) {
-				mmode_new(this, mystate->now, "+o", p1);
+			if(isopnow(this, p1)) {
+				continue;
 			}
+			if(haschanflags(this, "u") && !isallowedop(this, p1)) {
+				continue;
+			}
+			mmode_new(this, mystate->now, "+o", p1);
 		}
 		return;
 	case OER_WHICHCOMMAND_DOP:
@@ -1517,9 +1520,13 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
                 }
 		if(!strlen(restptr)) {
 			/* the messager wants to be de-opped */
-			if(isopnow(this, nick) && !(haschanflags(this, "D") && isallowedop(this, nick))) {
-                                mmode_new(this, mystate->now, "-o", nick);
+			if(!isopnow(this, nick)) {
+				return;
 			}
+			if(haschanflags(this, "D") && isallowedop(this, nick)) {
+				return;
+			}
+			mmode_new(this, mystate->now, "-o", nick);
 			return;
 		}
 		/* de-op all given nicks */
@@ -1530,9 +1537,13 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 				break;
 			}
 			ppos = nppos;
-			if(isopnow(this, p1) && !(haschanflags(this, "D") && isallowedop(this, p1))) {
-                                mmode_new(this, mystate->now, "-o", p1);
+			if(!isopnow(this, p1)) {
+				continue;
 			}
+			if(haschanflags(this, "D") && isallowedop(this, p1)) {
+				continue;
+			}
+			mmode_new(this, mystate->now, "-o", p1);
 		}
 		return;
 	case OER_WHICHCOMMAND_VOICE:
@@ -1634,7 +1645,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 				break;
 			}
 			ppos = nppos;
-			banuser(this, p1);
+			banuser(this, mystate->now, p1);
 		}
 		return;
 	case OER_WHICHCOMMAND_UNBAN:
@@ -1664,7 +1675,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 				break;
 			}
 			ppos = nppos;
-			unbanuser(this, p1);
+			unbanuser(this, mystate->now, p1);
 		}
 		return;
 	case OER_WHICHCOMMAND_BANKICK:
@@ -1690,8 +1701,8 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 		if((ppos = parse(restptr, ppos, " ", p1, STRINGLEN, 0)) < 0) {
 			return;
 		}
-		banuser(this, p1);
-		kickuser(this, p1, (strlen(restptr + ppos) > 0) ? restptr + ppos : NULL);
+		banuser(this, mystate->now - 1, p1);
+		kickuser(this, mystate->now, p1, (strlen(restptr + ppos) > 0) ? restptr + ppos : NULL);
 		return;
 	case OER_WHICHCOMMAND_KICK:
 #ifdef DEBUG
@@ -1716,7 +1727,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 		if((ppos = parse(restptr, ppos, " ", p1, STRINGLEN, 0)) < 0) {
 			return;
 		}
-		kickuser(this, p1, (strlen(restptr + ppos) > 0) ? restptr + ppos : NULL);
+		kickuser(this, mystate->now, p1, (strlen(restptr + ppos) > 0) ? restptr + ppos : NULL);
 		return;
 	case OER_WHICHCOMMAND_INVITE:
 #ifdef DEBUG
