@@ -3,39 +3,44 @@
 CURRDIR=`pwd`
 LOGTO="pre_install.log"
 
+case `uname` in
+  SunOS) ECHO="/usr/ucb/echo" ;;
+  *) ECHO="echo" ;;
+esac
+
 readln () {
-	echo -n "$1"
+	$ECHO -n "$1"
         IFS='@' read ans || exit 1
         [ -z "$ans" ] && ans=$2
 }
 
 if [ $# -ne 1 ]; then
-        echo "wrong number of arguments"
-        echo ""
+        $ECHO "wrong number of arguments"
+        $ECHO ""
         exit 1
 fi
 
 rm -f $LOGTO 2>&1 >/dev/null
 touch $LOGTO
 
-echo "Now configuring MySQL for oer+MySQL, see $LOGTO in case of errors"
-echo ""
-echo -n "Checking if I can find all the necesarry binaries... "
+$ECHO "Now configuring MySQL for oer+MySQL, see $LOGTO in case of errors"
+$ECHO ""
+$ECHO -n "Checking if I can find all the necesarry binaries... "
 
 if [ ! -x $1/mysqladmin ]; then
-	echo "mysqladmin not found in $1"
-	echo ""
+	$ECHO "mysqladmin not found in $1"
+	$ECHO ""
         exit 1
 fi
 
 if [ ! -x $1/mysql ]; then
-	echo "mysql not found in $1"
-        echo ""
+	$ECHO "mysql not found in $1"
+        $ECHO ""
         exit 1
 fi
 
-echo "ok"
-echo ""
+$ECHO "ok"
+$ECHO ""
 readln "Do you want to create the database (+ user) for oer+MySQL? [y/N] " "N"
 CREATEDB=$ans
 
@@ -44,124 +49,124 @@ if [ "$CREATEDB" = "y" ]; then
     HOST=$ans
     readln "Please specify the MySQL admin user [root] " "root"
     USER=$ans
-    stty -echo
+    stty -$ECHO
     readln "Please specify the MySQL admin password [] " ""
     PW=$ans
-    stty echo
-    echo ""
-    echo ""
-    echo -n "Attempting to connect to $HOST as $USER... "
+    stty $ECHO
+    $ECHO ""
+    $ECHO ""
+    $ECHO -n "Attempting to connect to $HOST as $USER... "
 
     if [ "$PW" = "" ]; then
 	LOGTHIS=`$1/mysqladmin -h $HOST -u $USER ping 2>&1`
 	RC=$?
-	echo $LOGTHIS >> $LOGTO
+	$ECHO $LOGTHIS >> $LOGTO
     else
 	LOGTHIS=`$1/mysqladmin -h $HOST -u $USER -p$PW ping 2>&1`
 	RC=$?
-	echo $LOGTHIS >> $LOGTO
+	$ECHO $LOGTHIS >> $LOGTO
     fi
 
     if [ $RC -eq 1 ]; then
-	echo "failed"
-	echo ""
+	$ECHO "failed"
+	$ECHO ""
         exit 1
     fi
 
-    echo "ok"
-    echo
+    $ECHO "ok"
+    $ECHO
     readln "What should your database be named [oerdb] " "oerdb"
     DB=$ans
-    echo ""
-    echo -n "Attempting to create database... "
+    $ECHO ""
+    $ECHO -n "Attempting to create database... "
 
     if [ "$PW" = "" ]; then
 	LOGTHIS=`$1/mysqladmin -h $HOST -u $USER create $DB 2>&1`
 	RC=$?
-        echo $LOGTHIS >> $LOGTO
+        $ECHO $LOGTHIS >> $LOGTO
     else
 	LOGTHIS=`$1/mysqladmin -h $HOST -u $USER -p$PW create $DB 2>&1`
 	RC=$?
-        echo $LOGTHIS >> $LOGTO
+        $ECHO $LOGTHIS >> $LOGTO
     fi
 
     if [ $RC -eq 1 ]; then
-	echo "failed"
-        echo ""
-	echo "Check that the database hasn't already been created"
-        echo "If it has, either drop it or skip this phase"
-	echo ""
+	$ECHO "failed"
+        $ECHO ""
+	$ECHO "Check that the database hasn't already been created"
+        $ECHO "If it has, either drop it or skip this phase"
+	$ECHO ""
         exit 1
     fi
 
-    echo "ok"
-    echo ""
+    $ECHO "ok"
+    $ECHO ""
 
     readln "What database user will be granted rights to $DB [oer] " "oer"
     DBUSER=$ans
-    stty -echo
+    stty -$ECHO
     readln "Please specify password for $DBUSER [] " ""
     DBUSERPW=$ans
-    stty echo
-    echo ""
+    stty $ECHO
+    $ECHO ""
     HOSTNAME=`hostname`
     GRANTFOR="$HOSTNAME localhost"
     for i in $GRANTFOR; do
-	echo -n "Attempting to grant rights to $DBUSER coming from $i... "
+	$ECHO -n "Attempting to grant rights to $DBUSER coming from $i... "
 
 	if [ "$PW" = "" ]; then
 
 	    if [ "$DBUSERPW" = "" ]; then
-		LOGTHIS=`( echo "GRANT ALL PRIVILEGES ON $DB.* TO $DBUSER@$i" | $1/mysql -h $HOST -u $USER ) 2>&1`
+		LOGTHIS=`( $ECHO "GRANT ALL PRIVILEGES ON $DB.* TO $DBUSER@$i" | $1/mysql -h $HOST -u $USER ) 2>&1`
 		RC=$?
-		echo $LOGTHIS >> $LOGTO
+		$ECHO $LOGTHIS >> $LOGTO
 	    else
-		LOGTHIS=`( echo "GRANT ALL PRIVILEGES ON $DB.* TO $DBUSER@$i IDENTIFIED BY '$DBUSERPW'" | $1/mysql -h $HOST -u $USER ) 2>&1`
+		LOGTHIS=`( $ECHO "GRANT ALL PRIVILEGES ON $DB.* TO $DBUSER@$i IDENTIFIED BY '$DBUSERPW'" | $1/mysql -h $HOST -u $USER ) 2>&1`
 		RC=$?
-		echo $LOGTHIS >> $LOGTO
+		$ECHO $LOGTHIS >> $LOGTO
 	    fi
 
 	else
 
 	    if [ "$DBUSERPW" = "" ]; then
-		LOGTHIS=`( echo "GRANT ALL PRIVILEGES ON $DB.* TO $DBUSER@$i" | $1/mysql -h $HOST -u $USER -p$PW ) 2>&1`
+		LOGTHIS=`( $ECHO "GRANT ALL PRIVILEGES ON $DB.* TO $DBUSER@$i" | $1/mysql -h $HOST -u $USER -p$PW ) 2>&1`
 		RC=$?
-		echo $LOGTHIS >> $LOGTO
+		$ECHO $LOGTHIS >> $LOGTO
 	    else
-		LOGTHIS=`( echo "GRANT ALL PRIVILEGES ON $DB.* TO $DBUSER@$i IDENTIFIED BY '$DBUSERPW'" | $1/mysql -h $HOST -u $USER -p$PW ) 2>&1`
+		LOGTHIS=`( $ECHO "GRANT ALL PRIVILEGES ON $DB.* TO $DBUSER@$i IDENTIFIED BY '$DBUSERPW'" | $1/mysql -h $HOST -u $USER -p$PW ) 2>&1`
 		RC=$?
-		echo $LOGTHIS >> $LOGTO
+		$ECHO $LOGTHIS >> $LOGTO
 	    fi
 
 	fi
 
 	if [ $RC -eq 1 ]; then
-	    echo "failed"
-	    echo ""
+	    $ECHO "failed"
+	    $ECHO ""
 	    exit 1
 	fi
 
-	echo "ok"
+	$ECHO "ok"
     done
-    echo -n "Attempting to FLUSH PRIVILEGES... "
+    $ECHO -n "Attempting to FLUSH PRIVILEGES... "
 
     if [ "$PW" = "" ]; then
-	LOGTHIS=`( echo "FLUSH PRIVILEGES" | $1/mysql -h $HOST -u $USER ) 2>&1`
+	LOGTHIS=`( $ECHO "FLUSH PRIVILEGES" | $1/mysql -h $HOST -u $USER ) 2>&1`
 	RC=$?
-        echo $LOGTHIS >> $LOGTO
+        $ECHO $LOGTHIS >> $LOGTO
     else
-	LOGTHIS=`( echo "FLUSH PRIVILEGES" | $1/mysql -h $HOST -u $USER -p$PW ) 2>&1`
+	LOGTHIS=`( $ECHO "FLUSH PRIVILEGES" | $1/mysql -h $HOST -u $USER -p$PW ) 2>&1`
 	RC=$?
-        echo $LOGTHIS >> $LOGTO
+        $ECHO $LOGTHIS >> $LOGTO
     fi
 
     if [ $RC -eq 1 ]; then
-	echo "failed"
-	echo ""
+	$ECHO "failed"
+	$ECHO ""
 	exit 1
     fi
 
-    echo "ok"
+    $ECHO "ok"
 else
     readln "Please specify the host where MySQL is running [localhost] " "localhost"
     HOST=$ans
@@ -169,70 +174,70 @@ else
     DB=$ans
     readln "Please specify the database user [oer] " "oer"
     DBUSER=$ans
-    stty -echo
+    stty -$ECHO
     readln "Please specify password for $DBUSER [] " ""
     DBUSERPW=$ans
-    stty echo
-    echo ""
-    echo ""
-    echo -n "Attempting to connect to $HOST as $DBUSER... "
+    stty $ECHO
+    $ECHO ""
+    $ECHO ""
+    $ECHO -n "Attempting to connect to $HOST as $DBUSER... "
 
     if [ "$DBUSERPW" = "" ]; then
 	LOGTHIS=`( $1/mysqladmin -h $HOST -u $DBUSER ping ) 2>&1`
 	RC=$?
-        echo $LOGTHIS >> $LOGTO
+        $ECHO $LOGTHIS >> $LOGTO
     else
 	LOGTHIS=`( $1/mysqladmin -h $HOST -u $DBUSER -p$DBUSERPW ping ) 2>&1`
 	RC=$?
-        echo $LOGTHIS >> $LOGTO
+        $ECHO $LOGTHIS >> $LOGTO
     fi
 
     if [ $RC -eq 1 ]; then
-	echo "failed"
-	echo ""
+	$ECHO "failed"
+	$ECHO ""
         exit 1
     fi
 
-    echo "ok"
+    $ECHO "ok"
 fi
 
-echo ""
+$ECHO ""
 readln "Do you want to create the initial tables for oer+MySQL? [y/N] " "N"
 CREATETABLES=$ans
 
 if [ "$CREATETABLES" = "y" ]; then
-    echo -n "Creating initial tables... "
+    $ECHO -n "Creating initial tables... "
 
     if [ "$DBUSERPW" = "" ]; then
 	LOGTHIS=`$1/mysql -h $HOST -u $DBUSER $DB < $CURRDIR/scripts/initial.sql 2>&1`
 	RC=$?
-        echo $LOGTHIS >> $LOGTO
+        $ECHO $LOGTHIS >> $LOGTO
     else
 	LOGTHIS=`$1/mysql -h $HOST -u $DBUSER -p$DBUSERPW $DB < $CURRDIR/scripts/initial.sql 2>&1`
 	RC=$?
-        echo $LOGTHIS >> $LOGTO
+        $ECHO $LOGTHIS >> $LOGTO
     fi
     
     if [ $RC -eq 1 ]; then
-	echo "failed"
-	echo ""
-	echo "Check that the tables haven't already been created"
-	echo "If they have, either drop them or skip this phase"
-	echo ""
+	$ECHO "failed"
+	$ECHO ""
+	$ECHO "Check that the tables haven't already been created"
+	$ECHO "If they have, either drop them or skip this phase"
+	$ECHO ""
 	exit 1
     fi
 
-    echo "ok"
+    $ECHO "ok"
 fi
 
-echo ""
+$ECHO ""
 readln "Do you want to create the initial configuration for oer+MySQL? [y/N] " "N"
 CREATECONF=$ans
 
 if [ "$CREATECONF" = "y" ]; then
-    echo ""
-    echo "oer+MySQL configuration follows"
-    echo ""
+    $ECHO ""
+    $ECHO "oer+MySQL configuration follows"
+    $ECHO ""
     readln "Please specify default IRC nick [oer] " "oer"
     NICK=$ans
     readln "Please specify alternate IRC nick [oeroer] " "oeroer"
@@ -283,8 +288,8 @@ if [ "$CREATECONF" = "y" ]; then
 
     INSERT_SERVERS="INSERT INTO servers VALUES ('$SERVER','$PORT','$MODES','$PINGFREQ','$PROT','$NOISE','$SERVERPW','$HANDLE',NULL)"
 
-    echo ""
-    echo -n "Importing data into database... "
+    $ECHO ""
+    $ECHO -n "Importing data into database... "
 
     for i in 1 2 3 4; do
 	case $i in
@@ -303,50 +308,50 @@ if [ "$CREATECONF" = "y" ]; then
 	esac
 
 	if [ "$DBUSERPW" = "" ]; then
-	    LOGTHIS=`( echo "$INSERT_COMMAND" | $1/mysql -h $HOST -u $DBUSER $DB ) 2>&1`
+	    LOGTHIS=`( $ECHO "$INSERT_COMMAND" | $1/mysql -h $HOST -u $DBUSER $DB ) 2>&1`
 	    RC=$?
-	    echo $LOGTHIS >> $LOGTO
+	    $ECHO $LOGTHIS >> $LOGTO
 	else
-	    LOGTHIS=`( echo "$INSERT_COMMAND" | $1/mysql -h $HOST -u $DBUSER -p$DBUSERPW $DB ) 2>&1`
+	    LOGTHIS=`( $ECHO "$INSERT_COMMAND" | $1/mysql -h $HOST -u $DBUSER -p$DBUSERPW $DB ) 2>&1`
 	    RC=$?
-	    echo $LOGTHIS >> $LOGTO
+	    $ECHO $LOGTHIS >> $LOGTO
 	fi
     
 	if [ $RC -eq 1 ]; then
-	    echo "failed"
-	    echo ""
-	    echo "Check that the settings haven't already been stored into the database"
-	    echo "If they have, either delete them or skip this phase"
-	    echo ""
+	    $ECHO "failed"
+	    $ECHO ""
+	    $ECHO "Check that the settings haven't already been stored into the database"
+	    $ECHO "If they have, either delete them or skip this phase"
+	    $ECHO ""
 	    exit 1
 	fi
 	
     done
-    echo "ok"
+    $ECHO "ok"
 fi
 
-echo ""
-echo -n "Creating oer+MySQL.conf... "
-echo "mysql::$HOST::$DB::$DBUSER::$DBUSERPW" > sample-configuration/oer+MySQL.conf
+$ECHO ""
+$ECHO -n "Creating oer+MySQL.conf... "
+$ECHO "mysql::$HOST::$DB::$DBUSER::$DBUSERPW" > sample-configuration/oer+MySQL.conf
 
 RC=$?
 
 if [ $RC -eq 1 ]; then
-    echo "failed"
-    echo ""
+    $ECHO "failed"
+    $ECHO ""
     exit 1
 fi
 
-echo "ident::$HANDLE" >> sample-configuration/oer+MySQL.conf
+$ECHO "ident::$HANDLE" >> sample-configuration/oer+MySQL.conf
 
 RC=$?
 
 if [ $RC -eq 1 ]; then
-    echo "failed"
-    echo ""
+    $ECHO "failed"
+    $ECHO ""
     exit 1
 fi
 
-echo "ok"
-echo ""
+$ECHO "ok"
+$ECHO ""
 exit 0
